*******************************************************************
* Impact of Trade Competition on Patenting
*******************************************************************

* David Dorn, January 10, 2019

* Input files:
* - firm_7507_main_data_final.dta (main data file)
* - firm_9107_hist_data_final.dta (for analyses using historical industry codes)
* - firm_9107_segm_data_final.dta (for analyses using historical industry segment codes)
* - firm_9107_nopat_data_final.dta (for analyses of non-patenting firms)
* - tech_9107_main_data_final.dta (for analyses at the technology class level)


*******************************************************************
* Administrative Commands
*******************************************************************

cap log close
set more off
clear

log using ../log/firm_7507_main_analysis_final.log, text replace

use ../dta/firm_7507_main_data_final.dta, clear


*******************************************************************
* Define main patent measure
* Define SE cluster variable
* Define default controls
*******************************************************************

local main="patent_usa"
local clustervar="sic87dd"
local controls="mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat*"


*******************************************************************
* TABLE 1 - Change in Firm Sales, Inputs, Value, and R&D
*******************************************************************

* US sales
local outcome="sale_us"

summ dhs_`outcome' d_import_usch_pd [aw=lx_patent_usa] if yr>=1991, detail
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t9907 [aw=lx_patent_usa] if yr>=1991, cluster(`clustervar')
summ dhs_`outcome' [aw=lx_patent_usa] if yr<1991 
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t8391 [aw=lx_patent_usa] if yr<1991, cluster(`clustervar')

* Global sales
local outcome="sale"

summ dhs_`outcome' [aw=lx_patent_usa] if yr>=1991
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t9907 [aw=lx_patent_usa] if yr>=1991, cluster(`clustervar')
summ dhs_`outcome' [aw=lx_patent_usa] if yr<1991 
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t8391 [aw=lx_patent_usa] if yr<1991, cluster(`clustervar')

* Global employment
local outcome="emp"

summ dhs_`outcome' [aw=lx_patent_usa] if yr>=1991
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t9907 [aw=lx_patent_usa] if yr>=1991, cluster(`clustervar')
summ dhs_`outcome' [aw=lx_patent_usa] if yr<1991 
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t8391 [aw=lx_patent_usa] if yr<1991, cluster(`clustervar')

* Global capital
local outcome="icapt"

summ dhs_`outcome' [aw=lx_patent_usa] if yr>=1991
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t9907 [aw=lx_patent_usa] if yr>=1991, cluster(`clustervar')
summ dhs_`outcome' [aw=lx_patent_usa] if yr<1991 
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t8391 [aw=lx_patent_usa] if yr<1991, cluster(`clustervar')

* Global book value
local outcome="bkvlps"

summ dhs_`outcome' [aw=lx_patent_usa] if yr>=1991
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t9907 [aw=lx_patent_usa] if yr>=1991, cluster(`clustervar')
summ dhs_`outcome' [aw=lx_patent_usa] if yr<1991 
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t8391 [aw=lx_patent_usa] if yr<1991, cluster(`clustervar')

* Global market value
local outcome="mkval"

summ dhs_`outcome' [aw=lx_patent_usa] if yr>=1991
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t9907 [aw=lx_patent_usa] if yr>=1991, cluster(`clustervar')
summ dhs_`outcome' [aw=lx_patent_usa] if yr<1991 
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t8391 [aw=lx_patent_usa] if yr<1991, cluster(`clustervar')

* Global r&d
local outcome="xrd"

summ dhs_`outcome' [aw=lx_patent_usa] if yr>=1991
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t9907 [aw=lx_patent_usa] if yr>=1991, cluster(`clustervar')
summ dhs_`outcome' [aw=lx_patent_usa] if yr<1991 
ivreg dhs_`outcome' (d_import_usch_pd=d_import_otch_pd_lag) mfg_* t8391 [aw=lx_patent_usa] if yr<1991, cluster(`clustervar')


*******************************************************************
* Table 2 - Change in Patents
*******************************************************************

* periods 91-99 and 99-07 (columns 1 and 2)
foreach y in 1991 1999 {
   summ dhs_`main' d_import_usch_pd [aw=lx_`main'] if yr==`y', detail
   reg dhs_`main' d_import_usch_pd [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   reg dhs_`main' d_import_usch_pd mfg_comp mfg_chempet [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg_comp mfg_chempet [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa [aw=lx_`main'] if yr==`y', cluster(`clustervar')
}

* stacked 91-99 and 99-07 (column 3)
summ dhs_`main' d_import_usch_pd [aw=lx_`main'] if yr>=1991, detail
reg dhs_`main' d_import_usch_pd t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')
reg dhs_`main' d_import_usch_pd mfg_comp mfg_chempet t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg_comp mfg_chempet t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')

*** periods 75-83 and 83-91 (columns 4 and 5)
foreach y in 1975 1983 {
   summ dhs_`main' d_import_usch_pd [aw=lx_`main'] if yr==`y', detail
   reg dhs_`main' d_import_usch_pd [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   reg dhs_`main' d_import_usch_pd mfg_comp mfg_chempet [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg_comp mfg_chempet [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss [aw=lx_`main'] if yr==`y', cluster(`clustervar')
   ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* [aw=lx_`main'] if yr==`y', cluster(`clustervar')
}

* stacked 75-83 and 83-91 (column 6)
summ dhs_`main' d_import_usch_pd [aw=lx_`main'] if yr<1991, detail
reg dhs_`main' d_import_usch_pd t8391 [aw=lx_`main'] if yr<1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) t8391 [aw=lx_`main'] if yr<1991, cluster(`clustervar')
reg dhs_`main' d_import_usch_pd mfg_comp mfg_chempet t8391 [aw=lx_`main'] if yr<1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg_comp mfg_chempet t8391 [aw=lx_`main'] if yr<1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* t8391 [aw=lx_`main'] if yr<1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* t8391 [aw=lx_`main'] if yr<1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss t8391 [aw=lx_`main'] if yr<1991, cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t8391 [aw=lx_`main'] if yr<1991, cluster(`clustervar')

* difference between treatment period and pre-period (column 7)
foreach var of varlist d_import_usch_pd d_import_otch_pd_lag {
   gen `var'_9199=`var'*(yr>=1991)
}
foreach var of varlist mfg* lx_sh_tcat* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss {
   gen `var'_7583=`var'*(yr<1991)
   gen `var'_9199=`var'*(yr>=1991)

}
reg dhs_`main' d_import_usch_pd d_import_usch_pd_9199 t8391 t9199 t9907 [aw=lx_`main'], cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd d_import_usch_pd_9199=d_import_otch_pd_lag*) t8391 t9199 t9907 [aw=lx_`main'], cluster(`clustervar')
reg dhs_`main' d_import_usch_pd d_import_usch_pd_9199 mfg*chem*_7583 mfg*chem*_9199 mfg*_comp*_7583 mfg*_comp*_9199 t8391 t9199 t9907 [aw=lx_`main'], cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd d_import_usch_pd_9199=d_import_otch_pd_lag*) mfg*chem*_7583 mfg*chem*_9199 mfg*_comp*_7583 mfg*_comp*_9199 t8391 t9199 t9907 [aw=lx_`main'], cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd d_import_usch_pd_9199=d_import_otch_pd_lag*) mfg*_7583 mfg*_9199 t8391 t9199 t9907 [aw=lx_`main'], cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd d_import_usch_pd_9199=d_import_otch_pd_lag*) mfg*_7583 mfg*_9199 l_ind*7583 l_ind*9199 t8391 t9199 t9907 [aw=lx_`main'], cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd d_import_usch_pd_9199=d_import_otch_pd_lag*) mfg*_7583 mfg*_9199 l_ind*7583 l_ind*9199 firm_us_7583 firm_us_9199 ln_sale*7583 ln_sale*9199 xrd*7583 xrd*9199 t8391 t9199 t9907 [aw=lx_`main'], cluster(`clustervar')
ivreg dhs_`main' (d_import_usch_pd d_import_usch_pd_9199=d_import_otch_pd_lag*) mfg*_7583 mfg*_9199 l_ind*7583 l_ind*9199 firm_us_7583 firm_us_9199 ln_sale*7583 ln_sale*9199 xrd*7583 xrd*9199 lx_sh_tcat*_7583 lx_sh_tcat*_9199 t8391 t9199 t9907 [aw=lx_`main'], cluster(`clustervar')

drop *_7583 *_9199


*******************************************************************
* TABLE 3 - Alternative IV Strategies
*******************************************************************

save temp.dta, replace

* keep 1991-2007 sample of firms with positive patents
* define industry FEs
keep if yr>=1991
keep if lx_patent_usa>0
keep if lx_patent_usa!=.
xi i.sic87dd
set matsize 2000

* US imports from China (OLS)
reg dhs_`main' d_import_usch_pd mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar') 
reg dhs_`main' d_import_usch_pd_9907 _Isic* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar') 

* Third country imports from China (Reduced form OLS)
reg dhs_`main' d_import_otch_pd_lag mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar') 
reg dhs_`main' d_import_otch_pd_9907 _Isic* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar') 

* NTR Gap (Reduced form OLS)
reg dhs_`main' ntrgap ntrgap_9907 mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar') 
reg dhs_`main' ntrgap_9907 _Isic* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar') 

* MFA Quotas (Reduced form OLS in 3-digit industries with positive exposure)
reg dhs_`main' mfa_schott mfa_schott_9907 mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if ((sic87dd>=2200 & sic87dd<=2399) | (sic87dd>=3130 & sic87dd<=3139) | (sic87dd>=3150 & sic87dd<=3199) | (sic87dd>=2060 & sic87dd<=2069) | (sic87dd>=2590 & sic87dd<=2599) | (sic87dd>=2750 & sic87dd<=2759) | (sic87dd>=2820 & sic87dd<=2829) | (sic87dd>=3630 & sic87dd<=3639) | (sic87dd>=3710 & sic87dd<=3719) | (sic87dd>=3990 & sic87dd<=3999) | (sic87dd>=5460 & sic87dd<=5469)  | (sic87dd>=5710 & sic87dd<=5719)  | (sic87dd>=5810 & sic87dd<=5819)), cluster(`clustervar') first
reg dhs_`main' mfa_schott_9907 _Isic* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* lag1_patent_usa lag2_patent_usa t9907 [aw=lx_`main'] if ((sic87dd>=2200 & sic87dd<=2399) | (sic87dd>=3130 & sic87dd<=3139) | (sic87dd>=3150 & sic87dd<=3199) | (sic87dd>=2060 & sic87dd<=2069) | (sic87dd>=2590 & sic87dd<=2599) | (sic87dd>=2750 & sic87dd<=2759) | (sic87dd>=2820 & sic87dd<=2829) | (sic87dd>=3630 & sic87dd<=3639) | (sic87dd>=3710 & sic87dd<=3719) | (sic87dd>=3990 & sic87dd<=3999) | (sic87dd>=5460 & sic87dd<=5469)  | (sic87dd>=5710 & sic87dd<=5719)  | (sic87dd>=5810 & sic87dd<=5819)), cluster(`clustervar') first

use temp.dta, clear


*******************************************************************
* TABLE 4 - Sample Splits
*******************************************************************

* split by sales per employee
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & l_se>ind_se_mean & l_se!=.
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_se>ind_se_mean & l_se!=., cluster(`clustervar')
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & l_se<=ind_se_mean & l_se!=. 
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_se<=ind_se_mean & l_se!=., cluster(`clustervar')

* split by capital intensity
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & l_ce>ind_ce_mean & l_ce!=.
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_ce>ind_ce_mean & l_ce!=., cluster(`clustervar')
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & l_ce<=ind_ce_mean & l_ce!=.
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_ce<=ind_ce_mean & l_ce!=., cluster(`clustervar')

* split by profitability
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & l_roi>ind_roi_mean & l_roi!=.
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_roi>ind_roi_mean & l_roi!=., cluster(`clustervar')
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & l_roi<=ind_roi_mean & l_roi!=.
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_roi<=ind_roi_mean & l_roi!=., cluster(`clustervar')

* split by debt to equity
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & l_de>ind_de_mean & l_de!=.
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_de>ind_de_mean & l_de!=., cluster(`clustervar')
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & l_de<=ind_de_mean & l_de!=. 
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_de<=ind_de_mean & l_de!=., cluster(`clustervar')

* test equality of coefficients
foreach k in se ce roi de {
	gen hictrl_const=(l_`k'>ind_`k'_mean & l_`k'!=.) 
	gen hi_d_import_usch_pd=d_import_usch_pd*(l_`k'>ind_`k'_mean & l_`k'!=.) 
	gen hi_d_import_otch_pd_lag=d_import_otch_pd_lag*(l_`k'>ind_`k'_mean & l_`k'!=.)
	foreach var of varlist mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 {
	      gen hictrl_`var'=`var'*(l_`k'>ind_`k'_mean & l_`k'!=.)  
	   }
	gen lo_d_import_usch_pd=d_import_usch_pd*(l_`k'<=ind_`k'_mean & l_`k'!=.) 
	gen lo_d_import_otch_pd_lag=d_import_otch_pd_lag*(l_`k'<=ind_`k'_mean & l_`k'!=.)
	foreach var of varlist mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 {
	      gen loctrl_`var'=`var'*(l_`k'<=ind_`k'_mean & l_`k'!=.)  
	   }
   
	ivreg dhs_`main' (lo_d_import_usch_pd hi_d_import_usch_pd=lo_d_import_otch_pd_lag hi_d_import_otch_pd_lag) hictrl_* loctrl_* [aw=lx_`main'] if yr>=1991 & l_`k'!=., cluster(`clustervar')
    disp "equality of coefficients, sample split `k'"
	test _b[lo_d_import_usch_pd]=_b[hi_d_import_usch_pd]
	drop hi_* lo_* hictrl_* loctrl_*
}


*******************************************************************
* APPENDIX TABLE 6 - Alternative Measurement of Industry Affilation
*******************************************************************

* main specification 
save temp.dta, replace
summ dhs_`main' [aw=lx_`main'] if yr>=1991
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')

* historical industry code if available 
use ../dta/firm_9107_hist_data_final.dta, clear
summ dhs_`main' [aw=lx_`main'] if yr>=1991
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')

* historical industry segment code if available 
use ../dta/firm_9107_segm_data_final.dta, clear
summ dhs_`main' [aw=lx_`main'] if yr>=1991
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')

* historical industry code only 
use ../dta/firm_9107_hist_data_final.dta, clear
summ dhs_`main'_hexact [aw=lx_`main'_hexact] if yr>=1991
ivreg dhs_`main'_hexact (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'_hexact] if yr>=1991, cluster(`clustervar')

* historical industry segment code only 
use ../dta/firm_9107_segm_data_final.dta, clear
summ dhs_`main'_sexact [aw=lx_`main'_sexact] if yr>=1991
ivreg dhs_`main'_sexact (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'_sexact] if yr>=1991, cluster(`clustervar')

* probability of industry change
use ../dta/firm_9107_hist_data_final.dta, clear
summ indchg [aw=lx_`main'_hexact] if yr>=1991
ivreg indchg (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'_hexact] if yr>=1991, cluster(`clustervar')

* probability of entering a new industry segment 
use ../dta/firm_9107_segm_data_final.dta, clear
summ seg_add [aw=lx_`main'_sexact] if yr>=1991
ivreg seg_add (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'_sexact] if yr>=1991, cluster(`clustervar')

* probability of leaving an industry segment 
use ../dta/firm_9107_segm_data_final.dta, clear
summ seg_drop [aw=lx_`main'_sexact] if yr>=1991
ivreg seg_drop (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'_sexact] if yr>=1991, cluster(`clustervar')

use temp.dta, clear


*******************************************************************
* APPENDIX TABLE 5 - Alternative Samples and Weights
*******************************************************************

* sample adjustment: exclude lag>6y
summ dhs_`main'_g6 [aw=lx_`main'] if yr>=1991 & lx_patent_usa_g6!=.
ivreg dhs_`main'_g6 (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & lx_patent_usa_g6!=., cluster(`clustervar')

* sample adjustment: exclude computer tech
summ dhs_`main'_excomp [aw=lx_`main'] if yr>=1991 & lx_patent_usa_excomp!=.
ivreg dhs_`main'_excomp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & lx_patent_usa_excomp!=., cluster(`clustervar')

* sample adjustment: exclude chemical/drug tech
summ dhs_`main'_exchdrg [aw=lx_`main'] if yr>=1991 & lx_patent_usa_exchdrg!=.
ivreg dhs_`main'_exchdrg (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & lx_patent_usa_exchdrg!=., cluster(`clustervar')

* sample adjustment: exclude manual
summ dhs_`main'_noman [aw=lx_`main'] if yr>=1991 & lx_patent_usa_noman!=.
ivreg dhs_`main'_noman (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & lx_patent_usa_noman!=., cluster(`clustervar')

* sample adjustment: exclude nber+manual
summ dhs_`main'_nameweb [aw=lx_`main'] if yr>=1991 & lx_patent_usa_nameweb!=.
ivreg dhs_`main'_nameweb (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & lx_patent_usa_nameweb!=., cluster(`clustervar')

* sample adjustment: balanced panel
summ dhs_`main' [aw=lx_`main'] if yr>=1991 & firmct==1
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & firmct==1, cluster(`clustervar')

* weight adjustment: citation-weighted
summ dhs_`main' [aw=lx_cites_std_usa] if yr>=1991 & firmct==1
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_cites_std_usa] if yr>=1991, cluster(`clustervar')

save temp.dta, replace
append using ../dta/firm_9107_nopat_data_final.dta

* weight adjustment: r&d-weighted
summ dhs_`main' [aw=lx_xrd] if yr>=1991 
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_xrd] if yr>=1991, cluster(`clustervar')

* weight adjustment: US sales-weighted
summ dhs_`main' [aw=lx_sale_us] if yr>=1991 
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_sale_us] if yr>=1991, cluster(`clustervar')

* weight adjustment: unweighted balanced panel of Compustat firms
summ dhs_`main' if yr>=1991 & firmct==1
ivreg dhs_`main' (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 if yr>=1991 & firmct==1, cluster(`clustervar')

use temp.dta, clear


*******************************************************************
* APPENDIX TABLE 7 - Analysis at the Technology-Class Level
*******************************************************************

save temp.dta, replace
use ../dta/tech_9107_main_data_final.dta, clear

* all corporate patents
summ dhs_patent_allcorp [aw=lx_`main'] if yr>=1991
ivreg dhs_patent_allcorp (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg_comp lx_mfg_chempet t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)
ivreg dhs_patent_allcorp (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg* lx_tcat* t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)
ivreg dhs_patent_allcorp (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg* lx_tcat* lag1_patent_allcorp lag2_patent_allcorp t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)

* all Compustat-covered corporate patents
summ dhs_patent_cscorp [aw=lx_`main'] if yr>=1991
ivreg dhs_patent_cscorp (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg_comp lx_mfg_chempet t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)
ivreg dhs_patent_cscorp (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg* lx_tcat* t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)
ivreg dhs_patent_cscorp (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg* lx_tcat* lag1_patent_cscorp lag2_patent_cscorp t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)

* all non-corporate patents
summ dhs_patent_noncorp [aw=lx_`main'] if yr>=1991
ivreg dhs_patent_noncorp (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg_comp lx_mfg_chempet t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)
ivreg dhs_patent_noncorp (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg* lx_tcat* lag1_patent_noncorp lag2_patent_noncorp t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)

* all corporate and non-corporate patents
summ dhs_patent_allentities [aw=lx_`main'] if yr>=1991
ivreg dhs_patent_allentities (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg_comp lx_mfg_chempet t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)
ivreg dhs_patent_allentities (dx_import_usch_pd=dx_import_otch_pd_lag) lx_mfg* lx_tcat* lag1_patent_allentities lag2_patent_allentities t9907 [aw=lx_`main'] if yr>=1991, cluster(techclass)

use temp.dta, clear
erase temp.dta


*******************************************************************
* APPENDIX TABLE 8 - Domestic and Foreign Inventors and Firms
*******************************************************************

* all US inventors patents
summ dhs_patent_usa [aw=lx_patent_usa] if yr>=1991
ivreg dhs_patent_usa (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_patent_usa] if yr>=1991, cluster(`clustervar')

* US inventor, US firm
summ dhs_patent_usa [aw=lx_patent_usa] if yr>=1991 & firm_us==1
ivreg dhs_patent_usa (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_patent_usa] if yr>=1991 & firm_us==1, cluster(`clustervar')

* US inventor, foreign firm
summ dhs_patent_usa [aw=lx_patent_usa] if yr>=1991 & firm_us==0
ivreg dhs_patent_usa (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_patent_usa] if yr>=1991 & firm_us==0, cluster(`clustervar')

* all US firm patents
summ dhs_patent [aw=lx_patent_usfirm] if yr>=1991 & firm_us==1
ivreg dhs_patent (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_patent_usfirm] if yr>=1991 & firm_us==1, cluster(`clustervar')

* US firm, US inventor
summ dhs_patent_usa [aw=lx_patent_usfirm] if yr>=1991 & firm_us==1 & lx_patent_usa!=.
ivreg dhs_patent_usa (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_patent_usfirm] if yr>=1991 & firm_us==1 & lx_patent_usa!=., cluster(`clustervar')

* US firm, foreign inventor
summ dhs_patent_f [aw=lx_patent_usfirm] if yr>=1991 & firm_us==1 & lx_patent_f!=.
ivreg dhs_patent_f (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_patent_usfirm] if yr>=1991 & firm_us==1 & lx_patent_f!=., cluster(`clustervar')

* all firms and inventors
summ dhs_patent [aw=lx_patent] if yr>=1991 
ivreg dhs_patent (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_patent] if yr>=1991, cluster(`clustervar')


*******************************************************************
* APPENDIX TABLE 9 - Innovation vs Sales
*******************************************************************

* US patents vs US sales
gen dhs_patentusa_sale=dhs_patent_usa-dhs_sale_us
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')

* split by sales per employee
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 & l_se>ind_se_mean & l_se!=.
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_se>ind_se_mean & l_se!=., cluster(`clustervar')
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 & l_se<=ind_se_mean & l_se!=. 
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_se<=ind_se_mean & l_se!=., cluster(`clustervar')

* split by capital intensity
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 & l_ce>ind_ce_mean & l_ce!=.
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_ce>ind_ce_mean & l_ce!=., cluster(`clustervar')
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 & l_ce<=ind_ce_mean & l_ce!=.
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_ce<=ind_ce_mean & l_ce!=., cluster(`clustervar')

* split by profitability
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 & l_roi>ind_roi_mean & l_roi!=.
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_roi>ind_roi_mean & l_roi!=., cluster(`clustervar')
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 & l_roi<=ind_roi_mean & l_roi!=.
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_roi<=ind_roi_mean & l_roi!=., cluster(`clustervar')

* split by debt to equity
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 & l_de>ind_de_mean & l_de!=.
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_de>ind_de_mean & l_de!=., cluster(`clustervar')
summ dhs_patentusa_sale [aw=lx_`main'] if yr>=1991 & l_de<=ind_de_mean & l_de!=.
ivreg dhs_patentusa_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_de<=ind_de_mean & l_de!=., cluster(`clustervar')

* test equality of coefficients
foreach k in se ce roi de {
	gen hictrl_const=(l_`k'>ind_`k'_mean & l_`k'!=.) 
	gen hi_d_import_usch_pd=d_import_usch_pd*(l_`k'>ind_`k'_mean & l_`k'!=.) 
	gen hi_d_import_otch_pd_lag=d_import_otch_pd_lag*(l_`k'>ind_`k'_mean & l_`k'!=.)
	foreach var of varlist mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 {
	      gen hictrl_`var'=`var'*(l_`k'>ind_`k'_mean & l_`k'!=.)  
	   }
	gen lo_d_import_usch_pd=d_import_usch_pd*(l_`k'<=ind_`k'_mean & l_`k'!=.) 
	gen lo_d_import_otch_pd_lag=d_import_otch_pd_lag*(l_`k'<=ind_`k'_mean & l_`k'!=.)
	foreach var of varlist mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 {
	      gen loctrl_`var'=`var'*(l_`k'<=ind_`k'_mean & l_`k'!=.)  
	   }
   
	ivreg dhs_patentusa_sale (lo_d_import_usch_pd hi_d_import_usch_pd=lo_d_import_otch_pd_lag hi_d_import_otch_pd_lag) hictrl_* loctrl_* [aw=lx_`main'] if yr>=1991 & l_`k'!=., cluster(`clustervar')
    disp "equality of coefficients, sample split `k'"
	test _b[lo_d_import_usch_pd]=_b[hi_d_import_usch_pd]
	drop hi_* lo_* hictrl_* loctrl_*
}

* Global patents vs sales
gen dhs_patent_sale=dhs_patent-dhs_sale
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')

* split by sales per employee
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 & l_se>ind_se_mean & l_se!=.
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_se>ind_se_mean & l_se!=., cluster(`clustervar')
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 & l_se<=ind_se_mean & l_se!=. 
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_se<=ind_se_mean & l_se!=., cluster(`clustervar')

* split by capital intensity
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 & l_ce>ind_ce_mean & l_ce!=.
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_ce>ind_ce_mean & l_ce!=., cluster(`clustervar')
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 & l_ce<=ind_ce_mean & l_ce!=.
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_ce<=ind_ce_mean & l_ce!=., cluster(`clustervar')

* split by profitability
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 & l_roi>ind_roi_mean & l_roi!=.
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_roi>ind_roi_mean & l_roi!=., cluster(`clustervar')
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 & l_roi<=ind_roi_mean & l_roi!=.
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_roi<=ind_roi_mean & l_roi!=., cluster(`clustervar')

* split by debt to equity
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 & l_de>ind_de_mean & l_de!=.
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_de>ind_de_mean & l_de!=., cluster(`clustervar')
summ dhs_patent_sale [aw=lx_`main'] if yr>=1991 & l_de<=ind_de_mean & l_de!=.
ivreg dhs_patent_sale (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_de<=ind_de_mean & l_de!=., cluster(`clustervar')

* test equality of coefficients
foreach k in se ce roi de {
	gen hictrl_const=(l_`k'>ind_`k'_mean & l_`k'!=.) 
	gen hi_d_import_usch_pd=d_import_usch_pd*(l_`k'>ind_`k'_mean & l_`k'!=.) 
	gen hi_d_import_otch_pd_lag=d_import_otch_pd_lag*(l_`k'>ind_`k'_mean & l_`k'!=.)
	foreach var of varlist mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 {
	      gen hictrl_`var'=`var'*(l_`k'>ind_`k'_mean & l_`k'!=.)  
	   }
	gen lo_d_import_usch_pd=d_import_usch_pd*(l_`k'<=ind_`k'_mean & l_`k'!=.) 
	gen lo_d_import_otch_pd_lag=d_import_otch_pd_lag*(l_`k'<=ind_`k'_mean & l_`k'!=.)
	foreach var of varlist mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 {
	      gen loctrl_`var'=`var'*(l_`k'<=ind_`k'_mean & l_`k'!=.)  
	   }
   
	ivreg dhs_patent_sale (lo_d_import_usch_pd hi_d_import_usch_pd=lo_d_import_otch_pd_lag hi_d_import_otch_pd_lag) hictrl_* loctrl_* [aw=lx_`main'] if yr>=1991 & l_`k'!=., cluster(`clustervar')
    disp "equality of coefficients, sample split `k'"
	test _b[lo_d_import_usch_pd]=_b[hi_d_import_usch_pd]
	drop hi_* lo_* hictrl_* loctrl_*
}

* Global patents vs employment
gen dhs_patent_emp=dhs_patent-dhs_emp
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991, cluster(`clustervar')

* split by sales per employee
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 & l_se>ind_se_mean & l_se!=.
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_se>ind_se_mean & l_se!=., cluster(`clustervar')
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 & l_se<=ind_se_mean & l_se!=. 
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_se<=ind_se_mean & l_se!=., cluster(`clustervar')

* split by capital intensity
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 & l_ce>ind_ce_mean & l_ce!=.
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_ce>ind_ce_mean & l_ce!=., cluster(`clustervar')
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 & l_ce<=ind_ce_mean & l_ce!=.
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_ce<=ind_ce_mean & l_ce!=., cluster(`clustervar')

* split by profitability
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 & l_roi>ind_roi_mean & l_roi!=.
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_roi>ind_roi_mean & l_roi!=., cluster(`clustervar')
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 & l_roi<=ind_roi_mean & l_roi!=.
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_roi<=ind_roi_mean & l_roi!=., cluster(`clustervar')

* split by debt to equity
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 & l_de>ind_de_mean & l_de!=.
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_de>ind_de_mean & l_de!=., cluster(`clustervar')
summ dhs_patent_emp [aw=lx_`main'] if yr>=1991 & l_de<=ind_de_mean & l_de!=.
ivreg dhs_patent_emp (d_import_usch_pd=d_import_otch_pd_lag) `controls' t9907 [aw=lx_`main'] if yr>=1991 & l_de<=ind_de_mean & l_de!=., cluster(`clustervar')

* test equality of coefficients
foreach k in se ce roi de {
	gen hictrl_const=(l_`k'>ind_`k'_mean & l_`k'!=.) 
	gen hi_d_import_usch_pd=d_import_usch_pd*(l_`k'>ind_`k'_mean & l_`k'!=.) 
	gen hi_d_import_otch_pd_lag=d_import_otch_pd_lag*(l_`k'>ind_`k'_mean & l_`k'!=.)
	foreach var of varlist mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 {
	      gen hictrl_`var'=`var'*(l_`k'>ind_`k'_mean & l_`k'!=.)  
	   }
	gen lo_d_import_usch_pd=d_import_usch_pd*(l_`k'<=ind_`k'_mean & l_`k'!=.) 
	gen lo_d_import_otch_pd_lag=d_import_otch_pd_lag*(l_`k'<=ind_`k'_mean & l_`k'!=.)
	foreach var of varlist mfg* l_ind* firm_us ln_sale_us xrd_sale ln_sale_us_miss xrd_sale_miss lx_sh_tcat* t9907 {
	      gen loctrl_`var'=`var'*(l_`k'<=ind_`k'_mean & l_`k'!=.)  
	   }
   
	ivreg dhs_patent_emp (lo_d_import_usch_pd hi_d_import_usch_pd=lo_d_import_otch_pd_lag hi_d_import_otch_pd_lag) hictrl_* loctrl_* [aw=lx_`main'] if yr>=1991 & l_`k'!=., cluster(`clustervar')
    disp "equality of coefficients, sample split `k'"
	test _b[lo_d_import_usch_pd]=_b[hi_d_import_usch_pd]
	drop hi_* lo_* hictrl_* loctrl_*
}


log close
